The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {blueycolors}


Title: Provides 'Bluey' Inspired Color Palettes
Version: 0.2.2
Description: Provides 'Bluey'-inspired color palettes and 'ggplot2' scales.
License: MIT + file LICENSE
URL: https://github.com/ekholme/blueycolors, https://ekholme.github.io/blueycolors/
BugReports: https://github.com/ekholme/blueycolors/issues
Encoding: UTF-8
Imports: ggplot2, grDevices
Suggests: scales, testthat (≥ 3.0.0)
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-09-14 17:34:43 UTC; ekholme
Author: Eric Ekholm [aut, cre, cph]
Maintainer: Eric Ekholm <eric.ekholm@gmail.com>
Repository: CRAN
Date/Publication: 2026-09-24 14:40:26 UTC

Available Bluey Color Palettes

Description

Use bluey_palette to extract palettes of the desired length

Usage

bluey_colors

Value

A named list of character vectors, where each vector contains hex color codes corresponding to a Bluey character palette (bluey, chilli, heeler, and socks).


Bluey ggplot 2 color scales

Description

ggplot2 fill and color scales derived from Bluey characters

Usage

scale_color_bluey(option = "bluey", direction = 1, ...)

scale_fill_bluey(option = "bluey", direction = 1, ...)

scale_color_bluey_c(option = "bluey", direction = 1, ...)

scale_fill_bluey_c(option = "bluey", direction = 1, ...)

Arguments

option

The name of the color palette to use. See bluey_palette for available options

direction

If greater than or equal to 0, it will return the standard direction; otherwise it will reverse the direction of the palette

...

Additional arguments passed to ggplot2 scale functions

Value

A ScaleDiscrete object that can be added to another ggplot object

Examples

library(ggplot2)
tmp <- data.frame(x = rnorm(100), y = rnorm(100), z = rep(c("a", "b", "c", "d"), 25))

# using a discrete scale
ggplot(tmp, aes(x, y, color = z)) +
  geom_point() +
  scale_color_bluey()

# changing the palette used when creating a discrete scale
ggplot(tmp, aes(x, y, color = z)) +
  geom_point() +
  scale_color_bluey(option = "socks")


Bluey Color Palette Constructor

Description

Extract a color palette of the desired length (maximum of length 5)

Usage

bluey_palette(option = "bluey", n = NULL)

Arguments

option

The name of the color palette to use. Current options are 'bluey', 'chilli', 'heeler', and 'socks'

n

The number of colors to return. Currently, all scales are limited to 5 colors

Value

a character vector of hex codes for the requested palette

Examples

bluey_palette("heeler")
bluey_palette("socks", n = 5)

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.